@@ -1,8 +1,11 @@
+import os
+
 import rich_click as click
 from rich_click import RichCommand, RichGroup
 
 from aws_pcluster_helpers.commands import cli_sinfo
 from aws_pcluster_helpers.commands import cli_gen_nxf_slurm_config
+from aws_pcluster_helpers.commands import cli_build_ami
 
 
 @click.group()
@@ -38,5 +41,14 @@ def gen_nxf_slurm_config(output: str, overwrite: bool, stdout: bool):
     cli_gen_nxf_slurm_config.main(output, overwrite, stdout)
 
 
+@click.option('--output', help="Path to output pcluster describe-image", required=True,
+              default=os.environ.get('PCLUSTER_BUILD_AMI_FILE'))
+@click.option('--region', help="Aws region to query", required=False, default=os.environ.get('AWS_DEFAULT_REGION'))
+@click.option("--image-id", help="Ami build ID", required=True, default=os.environ.get('PCLUSTER_BUILD_AMI_ID'))
+def build_ami(output, region, image_id):
+    click.echo("PCluster image builder watcher")
+    cli_build_ami.main(image_id=image_id, output_file=output, region=region)
+
+
 if __name__ == "__main__":
     cli()
